@@ -3,7 +3,8 @@
 ;; Copyright (C) 2025 Huang Feiyu
 
 ;; Author: Huang Feiyu <sibadake1@163.com>
-;; Version: 3.0
+;; Package-Version: 3.0.2
+;; Package-Revision: de48a1af4661
 ;; Package-Requires: ((emacs "27.1") (posframe "1.4.0") (eglot "1.8"))
 ;; Keywords: tools, languages, convenience, mouse, hover
 ;; URL: https://github.com/huangfeiyu/eldoc-mouse
@@ -135,6 +136,10 @@ A leading space make the buffer hidden."
 (defvar-local eldoc-mouse--original-track-mouse nil
   "The original buffer local value of variable `track-mouse'.")
 
+(defvar-local eldoc-mouse-bounds-of-thing-at-point-function nil
+  "The function which determines the bounds of the thing at the point.
+The function should return nil if nothing is interested at the point.")
+
 (defvar-local eldoc-mouse-eldoc-documentation-functions
     (list #'eldoc-mouse--eglot-eldoc-documentation-function #'eldoc-mouse--elisp-eldoc-documentation-function)
   "The `eldoc-documentation-functions' for `eldoc-mouse-mode'.
@@ -155,7 +160,7 @@ this list for specific mode.")
   "Show document at the cursor."
   (interactive)
   (eldoc-mouse--hide-posframe)
-  (when-let* ((symbol-bounds (bounds-of-thing-at-point 'symbol))
+  (when-let* ((symbol-bounds (eldoc-mouse--bounds-of-thing-at-point))
               (eldoc-documentation-functions (eldoc-mouse--eldoc-documentation-functions)))
     (setq eldoc-mouse-last-symbol-bounds symbol-bounds)
     (unless eldoc-mouse-mode
@@ -220,7 +225,7 @@ POS is the buffer position under the mouse cursor."
       (let ((eldoc-documentation-functions (eldoc-mouse--eldoc-documentation-functions)))
         (goto-char pos)
         (setq-local eldoc-mouse-last-symbol-bounds
-                    (bounds-of-thing-at-point 'symbol))
+                    (eldoc-mouse--bounds-of-thing-at-point))
         ;; Use (nth 4 (syntax-ppss)) to check if the mouse is over a code comment.
         ;; based on the answer from
         ;; https://emacs.stackexchange.com/questions/14269/14270#14270
@@ -254,6 +259,12 @@ POS is the buffer position under the mouse cursor."
           (run-with-idle-timer
            eldoc-mouse-idle-time nil #'eldoc-mouse-show-doc-at pos))))
 
+(defun eldoc-mouse--bounds-of-thing-at-point ()
+  "Determine the start and end buffer locations for the THING at point."
+  (if eldoc-mouse-bounds-of-thing-at-point-function
+      (funcall eldoc-mouse-bounds-of-thing-at-point-function)
+    (bounds-of-thing-at-point 'symbol)))
+
 (defun eldoc-mouse--eglot-eldoc-documentation-function (cb)
   "Modify the `eglot-hover-eldoc-function'.
 So it won't call `eglot--highlight-piggyback` with `CB`."
@@ -299,7 +310,7 @@ So it won't call `eglot--highlight-piggyback` with `CB`."
   (let* ((fun-list1 (seq-filter (lambda (f)
                                   (and (not (function-equal f #'eglot-hover-eldoc-function))
                                        (or (not (fboundp 'eglot-highlight-eldoc-function))
-                                           (not (function-equal f #'eglot-highlight-eldoc-function)))
+                                           (not (with-no-warnings (function-equal f #'eglot-highlight-eldoc-function))))
                                        (not (function-equal f #'eglot-signature-eldoc-function))))
                                 eldoc-documentation-functions))
          (fun-list2 (append eldoc-mouse-eldoc-documentation-functions fun-list1)))
